@@ -1,5 +1,5 @@
 from .base_command import BaseCommand
-import bond.database
+from bond.database import BondDatabase
 import bond.proto
 from .devices import DevicesCommand
 import datetime
@@ -8,6 +8,8 @@ import random
 import time
 import sys
 
+LEVEL_MAP = {"warn": 2, "info": 3, "debug": 4, "trace": 5}
+
 
 def do_livelog(bondid, ip, port):
     bond.proto.delete(bondid, topic="debug/livelog")
@@ -31,6 +33,10 @@ def listen(my_ip):
     sock.bind((UDP_IP, UDP_PORT))
     return sock, UDP_PORT
 
+def auto_int(string: str) -> int:
+    """Attempts to automatically detect the base of the input string and parse it as
+       an int"""
+    return int(string, 0)
 
 class LivelogCommand(BaseCommand):
     subcmd = "livelog"
@@ -38,34 +44,44 @@ class LivelogCommand(BaseCommand):
     arguments = [
         (["--ip"], {"help": "IP of log server"}),
         (["--port"], {"help": "UDP port of log server"}),
-        (["--warn"], {"help": "set verbosity to WARN", "action": "store_true"}),
-        (["--info"], {"help": "set verbosity to INFO", "action": "store_true"}),
         (
-            ["--debug"],
+            ["--level"],
             {
-                "help": "set verbosity to DEBUG (may slow the Bond)",
-                "action": "store_true",
+                "help": "set the verbosity: warn, info, debug (may slow the Bond), or trace (will make the bond unuseably slow, it's recommended to only use this in subys-level)",
+                "choices": LEVEL_MAP.keys(),
+            },
+        ),
+        (["--subsys"], {"help": "the subsys target to change the log level for", "type": auto_int}),
+        (
+            ["--subsys-level"],
+            {
+                "help": "set the verbosity for the given subsys: warn, info, debug, or trace",
+                "choices": LEVEL_MAP.keys(),
             },
         ),
     ]
 
     def run(self, args):
-        bondid = bond.database.get_assert_selected_bondid()
+        bondid = BondDatabase.get_assert_selected_bondid()
 
         log_fn = bondid + ".livelog"
 
-        if args.warn or args.info or args.debug:
-            if args.warn:
-                lvl = 2
-            if args.info:
-                lvl = 3
-            if args.debug:
-                lvl = 4
-            bond.proto.patch(bondid, topic="debug/syslog", body={"lvl": lvl})
+        if args.level:
+            bond.proto.patch(
+                bondid, topic="debug/syslog", body={"lvl": LEVEL_MAP[args.level]}
+            )
+        if args.subsys:
+            body = {"subsys": args.subsys}
+            if args.subsys_level:
+                body["lvl"] = LEVEL_MAP[args.subsys_level]
+            bond.proto.patch(
+                bondid, topic="debug/syslog", body=body,
+            )
+
 
         if args.ip is None:
             with open(log_fn, "w+") as log:
-                my_ip = get_my_ip(bond.database.get_bonds()[bondid]["ip"])
+                my_ip = get_my_ip(BondDatabase.get_bonds()[bondid]["ip"])
                 sock, UDP_PORT = listen(my_ip)
                 do_livelog(bondid, my_ip, UDP_PORT)
                 log.write("\n===== %s =====\n" % datetime.datetime.now())
